==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Widgets/LibraryBrowser/ts/LibraryBrowser_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>LibraryBrowser</name>
    <message>
        <location filename="../LibraryBrowser.js" line="+71"/>
        <source>audience</source>
        <translation>podľa odboru</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>creator</source>
        <translation>vytvoril</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>dimension</source>
        <translation>rozmer</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>levelOfDetail</source>
        <translation>podľa úrovne detailu</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>license</source>
        <translation>podľa licencie</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>perspective</source>
        <translation>podľa pohľadu</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>presentation</source>
        <translation>podľa prezentácia</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>publisher</source>
        <translation>vydavateľ</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>subject</source>
        <translation>predmet</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>title</source>
        <translation>názov</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Widgets</source>
        <translation>Pomôcky</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1153"/>
        <location filename="../LibraryBrowserInit.js" line="+19"/>
        <source>Library Browser</source>
        <translation>Prehliadač Knižnice</translation>
    </message>
    <message>
        <location line="-1145"/>
        <source>Icon</source>
        <translation>Ikona</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>List</source>
        <translation>Zoznam</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Choose Source Folder</source>
        <translation>Vybrať zdrojový adresár</translation>
    </message>
    <message>
        <location line="+685"/>
        <source>Page %1 of %2</source>
        <translation>Strana %1 z %2</translation>
    </message>
    <message>
        <location line="+235"/>
        <source>Updating icons...</source>
        <translation>Aktualizovať ikony...</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+219"/>
        <source>Abort</source>
        <translation>Prerušiť</translation>
    </message>
    <message>
        <location line="-27"/>
        <source>File:</source>
        <translation>Súbor:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Folder:</source>
        <translation>Adresár:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>License:</source>
        <translation>Licencia:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Attribute as:</source>
        <translation>Pomenované ako:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Creator:</source>
        <translation>Vytvoril:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Updating library index:</source>
        <translation>Aktualizovať Index:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>DB error</source>
        <translation>chyba DB</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plugin LibraryBrowser: cannot connect to DB.
Driver error: %1
Database error: %2
Database file: %3
Library browser will not be available.</source>
        <translation>Plugin LibraryBrowser: nedá sa pripojiť k DB.
Chyba ovládača: %1
Chyba databázy: %2
Súbor databázy: %3
Prehliadač Knižnica nebude k dispozícii.</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Source removed from part library: %1</source>
        <translation>Zdroj odstránený z časti knižnice: %1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Force database update.</source>
        <translation>Nútená aktualizácia databázy.</translation>
    </message>
    <message>
        <location line="+393"/>
        <source>&amp;Insert</source>
        <translation>Vlož&amp;iť</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Edit Script File...</source>
        <translation>&amp;Upraviť Skriptový súbor...</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Open &amp;SVG File...</source>
        <translation>Otvoriť &amp;SVG súbor...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Open...</source>
        <translation>&amp;Otvoriť...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>&amp;Edit...</source>
        <translation>&amp;Upraviť...</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>File Browser</source>
        <translation>Prieskumník</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>&amp;Show in %1...</source>
        <translation>&amp;Zobraziť  %1...</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>&amp;Remove from Favorites</source>
        <translation>Odst&amp;rániť z obľúbených</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Add to Favorites</source>
        <translation>Prid&amp;ať k obľúbeným</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>&amp;Regenerate Icon</source>
        <translation>&amp;Obnoviť ikonu</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Regenerate Icons</source>
        <translation>&amp;Obnoviť ikony</translation>
    </message>
    <message>
        <location filename="../LibraryBrowserInit.js" line="-11"/>
        <source>&amp;Library Browser</source>
        <translation>Preh&amp;liadač Knižnice</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Synchronization</source>
        <translation>Synchronizácia</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Update search index on startup</source>
        <translation>Aktualizovať hľadanie indexu pri štarte</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Display Options</source>
        <translation>Voľby zobrazenia</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Icon Size:</source>
        <translation>Veľkosť ikony:</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>View Mode:</source>
        <translation>Režim zobrazenia:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Number of items
shown in search results:</source>
        <translation>Počet položiek zobrazených
vo výsledku vyhľadania:</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Library Sources</source>
        <translation>Zdroje Knižnice</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Add...</source>
        <translation>Pridať...</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Remove</source>
        <translation>Odstrániť</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Up</source>
        <translation>Nahor</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Down</source>
        <translation>Nadol</translation>
    </message>
</context>
<context>
    <name>LibraryBrowserForm</name>
    <message>
        <location filename="../LibraryBrowser.ui" line="+28"/>
        <source>File System</source>
        <translation>Systém súborov</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation type="vanished">Tagy</translation>
    </message>
    <message>
        <location line="+60"/>
        <source>Search</source>
        <translation>Hľadať</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Look for:</source>
        <translation>Hľadať:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Clear</source>
        <translation>Vyčistiť</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Find</source>
        <translation>Nájsť</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Reset tag selection</source>
        <translation>Späť na výber tagov</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation type="vanished">prázdne</translation>
    </message>
    <message>
        <location line="+126"/>
        <source>Favorites</source>
        <translation>Obľúbené</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Insert selected item into drawing</source>
        <translation>Vložiť vybranú položku na výkres</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Update DB from file system</source>
        <translation>Aktualizovať DB zo systému súborov</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>0</source>
        <translation>0</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Widgets/LibraryBrowser/ts/LibraryBrowser_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>LibraryBrowser</name>
    <message>
        <location filename="../LibraryBrowser.js" line="+72"/>
        <source>audience</source>
        <translation>podľa odboru</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>creator</source>
        <translation>vytvoril</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>dimension</source>
        <translation>rozmer</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>levelOfDetail</source>
        <translation>podľa úrovne detailu</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>license</source>
        <translation>podľa licencie</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>perspective</source>
        <translation>podľa pohľadu</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>presentation</source>
        <translation>podľa prezentácia</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>publisher</source>
        <translation>vydavateľ</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>subject</source>
        <translation>predmet</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>title</source>
        <translation>názov</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Widgets</source>
        <translation>Pomôcky</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1158"/>
        <location filename="../LibraryBrowserInit.js" line="+19"/>
        <source>Library Browser</source>
        <translation>Prehliadač Knižnice</translation>
    </message>
    <message>
        <location line="-1150"/>
        <source>Icon</source>
        <translation>Ikona</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>List</source>
        <translation>Zoznam</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Choose Source Folder</source>
        <translation>Vybrať zdrojový adresár</translation>
    </message>
    <message>
        <location line="+688"/>
        <source>Page %1 of %2</source>
        <translation>Strana %1 z %2</translation>
    </message>
    <message>
        <location line="+237"/>
        <source>Updating icons...</source>
        <translation>Aktualizovať ikony...</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+219"/>
        <source>Abort</source>
        <translation>Prerušiť</translation>
    </message>
    <message>
        <location line="-27"/>
        <source>File:</source>
        <translation>Súbor:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Folder:</source>
        <translation>Adresár:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>License:</source>
        <translation>Licencia:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Attribute as:</source>
        <translation>Pomenované ako:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Creator:</source>
        <translation>Vytvoril:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Updating library index:</source>
        <translation>Aktualizuje sa zoznam:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>DB error</source>
        <translation>chyba DB</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plugin LibraryBrowser: cannot connect to DB.
Driver error: %1
Database error: %2
Database file: %3
Library browser will not be available.</source>
        <translation>Plugin LibraryBrowser: nedá sa pripojiť k DB.
Chyba ovládača: %1
Chyba databázy: %2
Súbor databázy: %3
Prehliadač Knižnica nebude k dispozícii.</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Source removed from part library: %1</source>
        <translation>Zdroj odstránený z časti knižnice: %1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Force database update.</source>
        <translation>Nútená aktualizácia databázy.</translation>
    </message>
    <message>
        <location line="+393"/>
        <source>&amp;Insert</source>
        <translation>Vlož&amp;iť</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Edit Script File...</source>
        <translation>&amp;Upraviť Skriptový súbor...</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Open &amp;SVG File...</source>
        <translation>Otvoriť &amp;SVG súbor...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Open...</source>
        <translation>&amp;Otvoriť...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>&amp;Edit...</source>
        <translation>&amp;Upraviť...</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>File Browser</source>
        <translation>Prieskumník</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>&amp;Show in %1...</source>
        <translation>&amp;Zobraziť  %1...</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>&amp;Remove from Favorites</source>
        <translation>Odst&amp;rániť z obľúbených</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Add to Favorites</source>
        <translation>Prid&amp;ať k obľúbeným</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>&amp;Regenerate Icon</source>
        <translation>&amp;Obnoviť ikonu</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Regenerate Icons</source>
        <translation>&amp;Obnoviť ikony</translation>
    </message>
    <message>
        <location filename="../LibraryBrowserInit.js" line="-11"/>
        <source>&amp;Library Browser</source>
        <translation>Preh&amp;liadač Knižnice</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Synchronization</source>
        <translation>Synchronizácia</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Update search index on startup</source>
        <translation>Pri štarte aktualizovať zoznam knižnice</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Display Options</source>
        <translation>Voľby zobrazenia</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Icon Size:</source>
        <translation>Veľkosť ikony:</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>View Mode:</source>
        <translation>Režim zobrazenia:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Number of items
shown in search results:</source>
        <translation>Počet položiek zobrazených
vo výsledku vyhľadania:</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Library Sources</source>
        <translation>Zdroje Knižnice</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Add...</source>
        <translation>Pridať...</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Remove</source>
        <translation>Odstrániť</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Up</source>
        <translation>Nahor</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Down</source>
        <translation>Nadol</translation>
    </message>
</context>
<context>
    <name>LibraryBrowserForm</name>
    <message>
        <location filename="../LibraryBrowser.ui" line="+28"/>
        <source>File System</source>
        <translation>Systém súborov</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation type="vanished">Tagy</translation>
    </message>
    <message>
        <location line="+60"/>
        <source>Search</source>
        <translation>Hľadať</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Look for:</source>
        <translation>Hľadať:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Clear</source>
        <translation>Vyčistiť</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Find</source>
        <translation>Nájsť</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Reset tag selection</source>
        <translation>Späť na výber tagov</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation type="vanished">prázdne</translation>
    </message>
    <message>
        <location line="+126"/>
        <source>Favorites</source>
        <translation>Obľúbené</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Insert selected item into drawing</source>
        <translation>Vložiť vybranú položku na výkres</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Update DB from file system</source>
        <translation>Aktualizovať DB zo systému súborov</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>0</source>
        <translation>0</translation>
    </message>
</context>
</TS>
